@@ -1,39 +1,57 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
-** This file is part of the Qt 3 compatibility classes of the Qt Toolkit.
+** This file is part of the Qt3Support module of the Qt Toolkit.
 **
-** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
-** LICENSE.QPL included in the packaging of this file.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** This file may be distributed and/or modified under the terms of the
-** GNU General Public License version 2 as published by the Free Software
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
+**
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
 ** Foundation and appearing in the file LICENSE.GPL included in the
-** packaging of this file.
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** See http://www.trolltech.com/pricing.html or email sales@trolltech.com for
-**   information about Qt Commercial License Agreements.
-** See http://www.trolltech.com/qpl/ for QPL licensing information.
-** See http://www.trolltech.com/gpl/ for GPL licensing information.
-**
-** Contact info@trolltech.com if any conditions of this licensing are
-** not clear to you.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #ifndef Q3LISTVIEW_H
 #define Q3LISTVIEW_H
 
-#include "Qt3Support/q3scrollview.h"
+#include <Qt3Support/q3scrollview.h>
+
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
+QT_MODULE(Qt3SupportLight)
 
 #ifndef QT_NO_LISTVIEW
 
-
 class QPixmap;
 class QFont;
 class Q3Header;
@@ -239,7 +257,7 @@ class Q_COMPAT_EXPORT Q3ListView : public Q3ScrollView
     Q_PROPERTY(RenameAction defaultRenameAction READ defaultRenameAction WRITE setDefaultRenameAction)
 
 public:
-    Q3ListView(QWidget* parent=0, const char* name=0, Qt::WFlags f = 0);
+    Q3ListView(QWidget* parent=0, const char* name=0, Qt::WindowFlags f = 0);
     ~Q3ListView();
 
     int treeStepSize() const;
@@ -349,7 +367,7 @@ public:
 
     void hideColumn(int column);
 
-public slots:
+public Q_SLOTS:
     virtual void clear();
     virtual void invertSelection();
     virtual void selectAll(bool select);
@@ -357,7 +375,7 @@ public slots:
     void setContentsPos(int x, int y);
     void adjustColumn(int col);
 
-signals:
+Q_SIGNALS:
     void selectionChanged();
     void selectionChanged(Q3ListViewItem *);
     void currentChanged(Q3ListViewItem *);
@@ -419,11 +437,11 @@ protected:
     virtual void paintEmptyArea(QPainter *, const QRect &);
     void changeEvent(QEvent *);
 
-protected slots:
+protected Q_SLOTS:
     void updateContents();
     void doAutoScroll();
 
-private slots:
+private Q_SLOTS:
     void changeSortColumn(int);
     void handleIndexChange();
     void updateDirtyItems();
@@ -584,4 +602,8 @@ private:
 
 #endif // QT_NO_LISTVIEW
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // Q3LISTVIEW_H
