@@ -1,36 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.0, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole copyright
-** holder for Qt Designer, grants users of the Qt/Eclipse Integration
-** plug-in the right for the Qt/Eclipse Integration to link to
-** functionality provided by Qt Designer and its related libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** Trolltech reserves all rights not expressly granted herein.
-**
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -49,6 +54,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 /*****************************************************************************
@@ -74,6 +81,10 @@ Q_CORE_EXPORT char *qstrcpy(char *dst, const char *src);
 Q_CORE_EXPORT char *qstrncpy(char *dst, const char *src, uint len);
 
 Q_CORE_EXPORT int qstrcmp(const char *str1, const char *str2);
+Q_CORE_EXPORT int qstrcmp(const QByteArray &str1, const QByteArray &str2);
+Q_CORE_EXPORT int qstrcmp(const QByteArray &str1, const char *str2);
+static inline int qstrcmp(const char *str1, const QByteArray &str2)
+{ return -qstrcmp(str2, str1); }
 
 inline int qstrncmp(const char *str1, const char *str2, uint len)
 {
@@ -132,8 +143,10 @@ public:
     void reserve(int size);
     void squeeze();
 
+#ifndef QT_NO_CAST_FROM_BYTEARRAY
     operator const char *() const;
     operator const void *() const;
+#endif
     char *data();
     const char *data() const;
     inline const char *constData() const;
@@ -141,17 +154,23 @@ public:
     bool isDetached() const;
     void clear();
 
+#ifdef Q_COMPILER_MANGLES_RETURN_TYPE
     const char at(int i) const;
     const char operator[](int i) const;
-    QByteRef operator[](int i);
     const char operator[](uint i) const;
+#else
+    char at(int i) const;
+    char operator[](int i) const;
+    char operator[](uint i) const;
+#endif
+    QByteRef operator[](int i);
     QByteRef operator[](uint i);
 
     int indexOf(char c, int from = 0) const;
-    inline int indexOf(const char *c, int from = 0) const;
+    int indexOf(const char *c, int from = 0) const;
     int indexOf(const QByteArray &a, int from = 0) const;
     int lastIndexOf(char c, int from = -1) const;
-    inline int lastIndexOf(const char *c, int from = -1) const;
+    int lastIndexOf(const char *c, int from = -1) const;
     int lastIndexOf(const QByteArray &a, int from = -1) const;
 
     QBool contains(char c) const;
@@ -185,10 +204,10 @@ public:
     QByteArray rightJustified(int width, char fill = ' ', bool truncate = false) const;
 
 #ifdef QT3_SUPPORT
-    inline QT3_SUPPORT QByteArray leftJustify(uint width, char fill = ' ', bool truncate = false) const
-    { return leftJustified(int(width), fill, truncate); }
-    inline QT3_SUPPORT QByteArray rightJustify(uint width, char fill = ' ', bool truncate = false) const
-    { return rightJustified(int(width), fill, truncate); }
+    inline QT3_SUPPORT QByteArray leftJustify(uint width, char aFill = ' ', bool aTruncate = false) const
+    { return leftJustified(int(width), aFill, aTruncate); }
+    inline QT3_SUPPORT QByteArray rightJustify(uint width, char aFill = ' ', bool aTruncate = false) const
+    { return rightJustified(int(width), aFill, aTruncate); }
 #endif
 
     QByteArray &prepend(char c);
@@ -196,6 +215,7 @@ public:
     QByteArray &prepend(const QByteArray &a);
     QByteArray &append(char c);
     QByteArray &append(const char *s);
+    QByteArray &append(const char *s, int len);
     QByteArray &append(const QByteArray &a);
     QByteArray &insert(int i, char c);
     QByteArray &insert(int i, const char *s);
@@ -206,6 +226,7 @@ public:
     QByteArray &replace(char before, const char *after);
     QByteArray &replace(char before, const QByteArray &after);
     QByteArray &replace(const char *before, const char *after);
+    QByteArray &replace(const char *before, int bsize, const char *after, int asize);
     QByteArray &replace(const QByteArray &before, const QByteArray &after);
     QByteArray &replace(const QByteArray &before, const char *after);
     QByteArray &replace(const char *before, const QByteArray &after);
@@ -216,6 +237,8 @@ public:
 
     QList<QByteArray> split(char sep) const;
 
+    QByteArray repeated(int times) const;
+
 #ifndef QT_NO_CAST_TO_ASCII
     QT_ASCII_CAST_WARN QByteArray &append(const QString &s);
     QT_ASCII_CAST_WARN QByteArray &insert(int i, const QString &s);
@@ -248,6 +271,9 @@ public:
     double toDouble(bool *ok = 0) const;
     QByteArray toBase64() const;
     QByteArray toHex() const;
+    QByteArray toPercentEncoding(const QByteArray &exclude = QByteArray(),
+                                 const QByteArray &include = QByteArray(),
+                                 char percent = '%') const;
 
     QByteArray &setNum(short, int base = 10);
     QByteArray &setNum(ushort, int base = 10);
@@ -266,6 +292,8 @@ public:
     static QByteArray fromRawData(const char *, int size);
     static QByteArray fromBase64(const QByteArray &base64);
     static QByteArray fromHex(const QByteArray &hexEncoded);
+    static QByteArray fromPercentEncoding(const QByteArray &pctEncoded, char percent = '%');
+
 
     typedef char *iterator;
     typedef const char *const_iterator;
@@ -320,8 +348,11 @@ public:
 private:
     operator QNoImplicitBoolCast() const;
     struct Data {
-        QBasicAtomic ref;
+        QBasicAtomicInt ref;
         int alloc, size;
+	// ### Qt 5.0: We need to add the missing capacity bit
+	// (like other tool classes have), to maintain the
+	// reserved memory on resize.
         char *data;
         char array[1];
     };
@@ -331,6 +362,7 @@ private:
     QByteArray(Data *dd, int /*dummy*/, int /*dummy*/) : d(dd) {}
     void realloc(int alloc);
     void expand(int i);
+    QByteArray nulTerminated() const;
 
     friend class QByteRef;
     friend class QString;
@@ -343,18 +375,31 @@ inline QByteArray::QByteArray(): d(&shared_null) { d->ref.ref(); }
 inline QByteArray::~QByteArray() { if (!d->ref.deref()) qFree(d); }
 inline int QByteArray::size() const
 { return d->size; }
+
+#ifdef Q_COMPILER_MANGLES_RETURN_TYPE
 inline const char QByteArray::at(int i) const
 { Q_ASSERT(i >= 0 && i < size()); return d->data[i]; }
 inline const char QByteArray::operator[](int i) const
 { Q_ASSERT(i >= 0 && i < size()); return d->data[i]; }
 inline const char QByteArray::operator[](uint i) const
 { Q_ASSERT(i < uint(size())); return d->data[i]; }
+#else
+inline char QByteArray::at(int i) const
+{ Q_ASSERT(i >= 0 && i < size()); return d->data[i]; }
+inline char QByteArray::operator[](int i) const
+{ Q_ASSERT(i >= 0 && i < size()); return d->data[i]; }
+inline char QByteArray::operator[](uint i) const
+{ Q_ASSERT(i < uint(size())); return d->data[i]; }
+#endif
+
 inline bool QByteArray::isEmpty() const
 { return d->size == 0; }
+#ifndef QT_NO_CAST_FROM_BYTEARRAY
 inline QByteArray::operator const char *() const
 { return d->data; }
 inline QByteArray::operator const void *() const
 { return d->data; }
+#endif
 inline char *QByteArray::data()
 { detach(); return d->data; }
 inline const char *QByteArray::data() const
@@ -368,8 +413,8 @@ inline bool QByteArray::isDetached() const
 inline QByteArray::QByteArray(const QByteArray &a) : d(a.d)
 { d->ref.ref(); }
 #ifdef QT3_SUPPORT
-inline QByteArray::QByteArray(int size) : d(&shared_null)
-{ d->ref.ref(); if (size > 0) fill('\0', size); }
+inline QByteArray::QByteArray(int aSize) : d(&shared_null)
+{ d->ref.ref(); if (aSize > 0) fill('\0', aSize); }
 #endif
 
 inline int QByteArray::capacity() const
@@ -388,13 +433,18 @@ class Q_CORE_EXPORT QByteRef {
         : a(array),i(idx) {}
     friend class QByteArray;
 public:
+#ifdef Q_COMPILER_MANGLES_RETURN_TYPE
     inline operator const char() const
         { return i < a.d->size ? a.d->data[i] : 0; }
+#else
+    inline operator char() const
+        { return i < a.d->size ? a.d->data[i] : 0; }
+#endif
     inline QByteRef &operator=(char c)
-        { if (a.d->ref != 1 || i >= a.d->size) a.expand(i);
+        { if (i >= a.d->size) a.expand(i); else a.detach();
           a.d->data[i] = c;  return *this; }
     inline QByteRef &operator=(const QByteRef &c)
-        { if (a.d->ref != 1 || i >= a.d->size) a.expand(i);
+        { if (i >= a.d->size) a.expand(i); else a.detach();
           a.d->data[i] = c.a.d->data[c.i];  return *this; }
     inline bool operator==(char c) const
     { return a.d->data[i] == c; }
@@ -449,37 +499,37 @@ inline QBool QByteArray::contains(const QByteArray &a) const
 inline QBool QByteArray::contains(char c) const
 { return QBool(indexOf(c) != -1); }
 inline bool operator==(const QByteArray &a1, const QByteArray &a2)
-{ return (a1.size() == a2.size()) && (memcmp(a1, a2, a1.size())==0); }
+{ return (a1.size() == a2.size()) && (memcmp(a1.constData(), a2.constData(), a1.size())==0); }
 inline bool operator==(const QByteArray &a1, const char *a2)
-{ return a2 ? strcmp(a1,a2) == 0 : a1.isEmpty(); }
+{ return a2 ? qstrcmp(a1,a2) == 0 : a1.isEmpty(); }
 inline bool operator==(const char *a1, const QByteArray &a2)
-{ return a1 ? strcmp(a1,a2) == 0 : a2.isEmpty(); }
+{ return a1 ? qstrcmp(a1,a2) == 0 : a2.isEmpty(); }
 inline bool operator!=(const QByteArray &a1, const QByteArray &a2)
 { return !(a1==a2); }
 inline bool operator!=(const QByteArray &a1, const char *a2)
-{ return a2 ? strcmp(a1,a2) != 0 : !a1.isEmpty(); }
+{ return a2 ? qstrcmp(a1,a2) != 0 : !a1.isEmpty(); }
 inline bool operator!=(const char *a1, const QByteArray &a2)
-{ return a1 ? strcmp(a1,a2) != 0 : !a2.isEmpty(); }
+{ return a1 ? qstrcmp(a1,a2) != 0 : !a2.isEmpty(); }
 inline bool operator<(const QByteArray &a1, const QByteArray &a2)
-{ return strcmp(a1, a2) < 0; }
+{ return qstrcmp(a1, a2) < 0; }
  inline bool operator<(const QByteArray &a1, const char *a2)
 { return qstrcmp(a1, a2) < 0; }
 inline bool operator<(const char *a1, const QByteArray &a2)
 { return qstrcmp(a1, a2) < 0; }
 inline bool operator<=(const QByteArray &a1, const QByteArray &a2)
-{ return strcmp(a1, a2) <= 0; }
+{ return qstrcmp(a1, a2) <= 0; }
 inline bool operator<=(const QByteArray &a1, const char *a2)
 { return qstrcmp(a1, a2) <= 0; }
 inline bool operator<=(const char *a1, const QByteArray &a2)
 { return qstrcmp(a1, a2) <= 0; }
 inline bool operator>(const QByteArray &a1, const QByteArray &a2)
-{ return strcmp(a1, a2) > 0; }
+{ return qstrcmp(a1, a2) > 0; }
 inline bool operator>(const QByteArray &a1, const char *a2)
 { return qstrcmp(a1, a2) > 0; }
 inline bool operator>(const char *a1, const QByteArray &a2)
 { return qstrcmp(a1, a2) > 0; }
 inline bool operator>=(const QByteArray &a1, const QByteArray &a2)
-{ return strcmp(a1, a2) >= 0; }
+{ return qstrcmp(a1, a2) >= 0; }
 inline bool operator>=(const QByteArray &a1, const char *a2)
 { return qstrcmp(a1, a2) >= 0; }
 inline bool operator>=(const char *a1, const QByteArray &a2)
@@ -494,22 +544,14 @@ inline const QByteArray operator+(const char *a1, const QByteArray &a2)
 { return QByteArray(a1) += a2; }
 inline const QByteArray operator+(char a1, const QByteArray &a2)
 { return QByteArray(&a1, 1) += a2; }
-inline int QByteArray::indexOf(const char *c, int i) const
-{ return indexOf(fromRawData(c, qstrlen(c)), i); }
-inline int QByteArray::lastIndexOf(const char *c, int i) const
-{ return lastIndexOf(fromRawData(c, qstrlen(c)), i); }
 inline QBool QByteArray::contains(const char *c) const
-{ return contains(fromRawData(c, qstrlen(c))); }
-inline QByteArray &QByteArray::replace(int index, int len, const char *c)
-{ return replace(index, len, fromRawData(c, qstrlen(c))); }
+{ return QBool(indexOf(c) != -1); }
 inline QByteArray &QByteArray::replace(char before, const char *c)
-{ return replace(before, fromRawData(c, qstrlen(c))); }
+{ return replace(&before, 1, c, qstrlen(c)); }
 inline QByteArray &QByteArray::replace(const QByteArray &before, const char *c)
-{ return replace(before, fromRawData(c, qstrlen(c))); }
-inline QByteArray &QByteArray::replace(const char *c, const QByteArray &after)
-{ return replace(fromRawData(c, qstrlen(c)), after); }
+{ return replace(before.constData(), before.size(), c, qstrlen(c)); }
 inline QByteArray &QByteArray::replace(const char *before, const char *after)
-{ return replace(fromRawData(before, qstrlen(before)), fromRawData(after, qstrlen(after))); }
+{ return replace(before, qstrlen(before), after, qstrlen(after)); }
 
 inline QByteArray &QByteArray::setNum(short n, int base)
 { return setNum(qlonglong(n), base); }
@@ -540,6 +582,8 @@ inline QByteArray qUncompress(const QByteArray& data)
 Q_DECLARE_TYPEINFO(QByteArray, Q_MOVABLE_TYPE);
 Q_DECLARE_SHARED(QByteArray)
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QBYTEARRAY_H
