@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -29,6 +47,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 class QDir;
@@ -64,6 +84,7 @@ public:
     QString baseName() const;
     QString completeBaseName() const;
     QString suffix() const;
+    QString bundleName() const;
     QString completeSuffix() const;
 
     QString path() const;
@@ -85,6 +106,7 @@ public:
     bool isDir() const;
     bool isSymLink() const;
     bool isRoot() const;
+    bool isBundle() const;
 
     QString readLink() const;
     inline QString symLinkTarget() const { return readLink(); }
@@ -138,7 +160,7 @@ public:
     inline QT3_SUPPORT bool convertToAbs() { return makeAbsolute(); }
 #if !defined(Q_NO_TYPESAFE_FLAGS)
     inline QT3_SUPPORT bool permission(PermissionSpec permissions) const
-    { return permission(QFile::Permissions((int)permissions)); }
+    { return permission(QFile::Permissions(static_cast<int>(permissions))); }
 #endif
 #endif
 
@@ -158,6 +180,8 @@ typedef QList<QFileInfo> QFileInfoList;
 typedef QList<QFileInfo>::Iterator QFileInfoListIterator;
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QFILEINFO_H
