@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2007 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -26,22 +44,102 @@
 
 #include <stddef.h>
 
-#define QT_VERSION_STR   "4.3.0"
+#define QT_VERSION_STR "4.5.3"
 /*
    QT_VERSION is (major << 16) + (minor << 8) + patch.
 */
-#define QT_VERSION 0x040300
+#define QT_VERSION 0x040503
 /*
-   can be used like #if (QT_VERSION >= QT_VERSION_CHECK(4, 3, 0))
+   can be used like #if (QT_VERSION >= QT_VERSION_CHECK(4, 4, 0))
 */
 #define QT_VERSION_CHECK(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
 
-#define QT_PACKAGEDATE_STR "2007-05-25"
+#define QT_PACKAGEDATE_STR "2009-09-29"
+
+#define QT_PACKAGE_TAG "gfc42f5c26bbc257cf782679f7b40075e05322647"
 
 #if !defined(QT_BUILD_MOC)
 #include <QtCore/qconfig.h>
 #endif
 
+#ifdef __cplusplus
+
+#ifndef QT_NAMESPACE /* user namespace */
+
+# define QT_PREPEND_NAMESPACE(name) ::name
+# define QT_USE_NAMESPACE
+# define QT_BEGIN_NAMESPACE
+# define QT_END_NAMESPACE
+# define QT_BEGIN_INCLUDE_NAMESPACE
+# define QT_END_INCLUDE_NAMESPACE
+# define QT_BEGIN_MOC_NAMESPACE
+# define QT_END_MOC_NAMESPACE
+# define QT_FORWARD_DECLARE_CLASS(name) class name;
+# define QT_FORWARD_DECLARE_STRUCT(name) struct name;
+# define QT_MANGLE_NAMESPACE(name) name
+
+#else /* user namespace */
+
+# define QT_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
+# define QT_USE_NAMESPACE using namespace ::QT_NAMESPACE;
+# define QT_BEGIN_NAMESPACE namespace QT_NAMESPACE {
+# define QT_END_NAMESPACE }
+# define QT_BEGIN_INCLUDE_NAMESPACE }
+# define QT_END_INCLUDE_NAMESPACE namespace QT_NAMESPACE {
+# define QT_BEGIN_MOC_NAMESPACE QT_USE_NAMESPACE
+# define QT_END_MOC_NAMESPACE
+# define QT_FORWARD_DECLARE_CLASS(name) \
+    QT_BEGIN_NAMESPACE class name; QT_END_NAMESPACE \
+    using QT_PREPEND_NAMESPACE(name);
+
+# define QT_FORWARD_DECLARE_STRUCT(name) \
+    QT_BEGIN_NAMESPACE struct name; QT_END_NAMESPACE \
+    using QT_PREPEND_NAMESPACE(name);
+
+# define QT_MANGLE_NAMESPACE0(x) x
+# define QT_MANGLE_NAMESPACE1(a, b) a##_##b
+# define QT_MANGLE_NAMESPACE2(a, b) QT_MANGLE_NAMESPACE1(a,b)
+# define QT_MANGLE_NAMESPACE(name) QT_MANGLE_NAMESPACE2( \
+        QT_MANGLE_NAMESPACE0(name), QT_MANGLE_NAMESPACE0(QT_NAMESPACE))
+
+namespace QT_NAMESPACE {}
+
+# ifndef QT_BOOTSTRAPPED
+# ifndef QT_NO_USING_NAMESPACE
+   /*
+    This expands to a "using QT_NAMESPACE" also in _header files_.
+    It is the only way the feature can be used without too much
+    pain, but if people _really_ do not want it they can add
+    DEFINES += QT_NO_USING_NAMESPACE to theur .pro files.
+    */
+   QT_USE_NAMESPACE
+# endif
+# endif
+
+#endif /* user namespace */
+
+#else /* __cplusplus */
+
+# define QT_BEGIN_NAMESPACE
+# define QT_END_NAMESPACE
+# define QT_USE_NAMESPACE
+# define QT_BEGIN_INCLUDE_NAMESPACE
+# define QT_END_INCLUDE_NAMESPACE
+
+#endif /* __cplusplus */
+
+#if defined(Q_OS_MAC) && !defined(Q_CC_INTEL)
+#define QT_BEGIN_HEADER extern "C++" {
+#define QT_END_HEADER }
+#define QT_BEGIN_INCLUDE_HEADER }
+#define QT_END_INCLUDE_HEADER extern "C++" {
+#else
+#define QT_BEGIN_HEADER
+#define QT_END_HEADER
+#define QT_BEGIN_INCLUDE_HEADER
+#define QT_END_INCLUDE_HEADER extern "C++"
+#endif
+
 /*
    The operating system, must be one of: (Q_OS_x)
 
@@ -50,6 +148,7 @@
      OS2      - OS/2
      OS2EMX   - XFree86 on OS/2 (not PM)
      WIN32    - Win32 (Windows 95/98/ME and Windows NT/2000/XP)
+     WINCE    - WinCE (Windows CE 5.0)
      CYGWIN   - Cygwin
      SOLARIS  - Sun Solaris
      HPUX     - HP-UX
@@ -97,7 +196,11 @@
 #  define Q_OS_WIN32
 #  define Q_OS_WIN64
 #elif !defined(SAG_COM) && (defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(__NT__))
-#  define Q_OS_WIN32
+#  if defined(WINCE) || defined(_WIN32_WCE)
+#    define Q_OS_WINCE
+#  else
+#    define Q_OS_WIN32
+#  endif
 #elif defined(__MWERKS__) && defined(__INTEL__)
 #  define Q_OS_WIN32
 #elif defined(__sun) || defined(sun)
@@ -153,7 +256,7 @@
 #  error "Qt has not been ported to this OS - talk to qt-bugs@trolltech.com"
 #endif
 
-#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64)
+#if defined(Q_OS_WIN32) || defined(Q_OS_WIN64) || defined(Q_OS_WINCE)
 #  define Q_OS_WIN
 #endif
 
@@ -167,6 +270,19 @@
 #  endif
 #endif
 
+#ifdef AUTODETECT_COCOA
+#  ifdef Q_OS_MAC64
+#    define QT_MAC_USE_COCOA 1
+#    define QT_BUILD_KEY QT_BUILD_KEY_COCOA
+#  else
+#    define QT_BUILD_KEY QT_BUILD_KEY_CARBON
+#  endif
+#endif
+
+#if defined(Q_OS_MAC64) && !defined(QT_MAC_USE_COCOA) && !defined(QT_BUILD_QMAKE)
+#error "You are building a 64-bit application, but using a 32-bit version of Qt. Check your build configuration."
+#endif
+
 #if defined(Q_OS_MSDOS) || defined(Q_OS_OS2) || defined(Q_OS_WIN)
 #  undef Q_OS_UNIX
 #elif !defined(Q_OS_UNIX)
@@ -177,6 +293,44 @@
 #  define QT_LARGEFILE_SUPPORT 64
 #endif
 
+#ifdef Q_OS_DARWIN
+#  ifdef MAC_OS_X_VERSION_MIN_REQUIRED
+#    undef MAC_OS_X_VERSION_MIN_REQUIRED
+#  endif
+#  define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_3
+#  include <AvailabilityMacros.h>
+#  if !defined(MAC_OS_X_VERSION_10_3)
+#     define MAC_OS_X_VERSION_10_3 MAC_OS_X_VERSION_10_2 + 1
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_4)
+#       define MAC_OS_X_VERSION_10_4 MAC_OS_X_VERSION_10_3 + 1
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_5)
+#       define MAC_OS_X_VERSION_10_5 MAC_OS_X_VERSION_10_4 + 1
+#  endif
+#  if !defined(MAC_OS_X_VERSION_10_6)
+#       define MAC_OS_X_VERSION_10_6 MAC_OS_X_VERSION_10_5 + 1
+#  endif
+#  if (MAC_OS_X_VERSION_MAX_ALLOWED == MAC_OS_X_VERSION_10_6)
+#    warning "Support for this version of Mac OS X is still preliminary"
+#  endif
+#  if (MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_6)
+#    error "This version of Mac OS X is unsupported"
+#  endif
+#endif
+
+#ifdef QT_MAC_USE_COCOA
+#define QT_MAC_NO_QUICKDRAW 1
+#endif
+
+#ifdef __LSB_VERSION__
+#  if __LSB_VERSION__ < 40
+#    error "This version of the Linux Standard Base is unsupported"
+#  endif
+#ifndef QT_LINUXBASE
+#  define QT_LINUXBASE
+#endif
+#endif
 
 /*
    The compiler, must be one of: (Q_CC_x)
@@ -201,6 +355,8 @@
      HIGHC    - MetaWare High C/C++
      PGI      - Portland Group C++
      GHS      - Green Hills Optimizing C++ Compilers
+     RVCT     - ARM Realview Compiler Suite
+
 
    Should be sorted most to least authoritative.
 */
@@ -227,6 +383,7 @@
 /* proper support of bool for _MSC_VER >= 1100 */
 #  define Q_CANNOT_DELETE_CONSTANT
 #  define Q_OUTOFLINE_TEMPLATE inline
+#  define Q_NO_TEMPLATE_FRIENDS
 #  define QT_NO_PARTIAL_TEMPLATE_SPECIALIZATION
 /* Visual C++.Net issues for _MSC_VER >= 1300 */
 #  if _MSC_VER >= 1300
@@ -242,6 +399,8 @@
 #  endif
 #  if _MSC_VER < 1310
 #     define QT_NO_QOBJECT_CHECK
+#     define Q_TYPENAME
+#     define QT_NO_TEMPLATE_TEMPLATE_PARAMETERS
 #  endif
 /* Intel C++ disguising as Visual C++: the `using' keyword avoids warnings */
 #  if defined(__INTEL_COMPILER)
@@ -287,6 +446,9 @@
 #    define QT_NO_QWS_CURSOR
 #  endif
 
+#elif defined(__CC_ARM)
+#  define Q_CC_RVCT
+
 #elif defined(__GNUC__)
 #  define Q_CC_GNU
 #  define Q_C_CALLBACKS
@@ -296,6 +458,7 @@
 #  if defined(__INTEL_COMPILER)
 /* Intel C++ also masquerades as GCC 3.2.0 */
 #    define Q_CC_INTEL
+#    define Q_NO_TEMPLATE_FRIENDS
 #  endif
 #  ifdef __APPLE__
 #    define Q_NO_DEPRECATED_CONSTRUCTORS
@@ -312,13 +475,20 @@
 #  if defined(Q_OS_HPUX) && __GNUC__ == 3 && __GNUC_MINOR__ >= 1
 #    define Q_WRONG_SB_CTYPE_MACROS
 #  endif
+/* GCC <= 3.3 cannot handle template friends */
+#  if __GNUC__ < 3 || (__GNUC__ == 3 && __GNUC_MINOR__ <= 3)
+#    define Q_NO_TEMPLATE_FRIENDS
+#  endif
 /* Apple's GCC 3.1 chokes on our streaming qDebug() */
 #  if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
 #    define Q_BROKEN_DEBUG_STREAM
 #  endif
-#  if (defined(__arm__) || defined(__ARMEL__)) && !defined(QT_MOC_CPP)
+#  if (defined(Q_CC_GNU) || defined(Q_CC_INTEL)) && !defined(QT_MOC_CPP)
 #    define Q_PACKED __attribute__ ((__packed__))
 #    define Q_NO_PACKED_REFERENCE
+#    ifndef __ARM_EABI__
+#      define QT_NO_ARM_EABI
+#    endif
 #  endif
 
 /* IBM compiler versions are a bit messy. There are actually two products:
@@ -398,7 +568,7 @@
    __EDG documented by SGI, observed on MIPSpro 7.3.1.1 and KAI C++ 4.0b
    __EDG__ documented in EDG online docs, observed on Compaq C++ V6.3-002
    and PGI C++ 5.2-4 */
-#elif defined(__EDG) || defined(__EDG__)
+#elif !defined(Q_OS_HPUX) && (defined(__EDG) || defined(__EDG__))
 #  define Q_CC_EDG
 /* From the EDG documentation (does not seem to apply to Compaq C++):
    _BOOL
@@ -456,6 +626,7 @@
 #  elif defined(__sgi)
 #    define Q_CC_MIPS
 #    define Q_NO_USING_KEYWORD /* ### check "using" status */
+#    define Q_NO_TEMPLATE_FRIENDS
 #    if defined(_COMPILER_VERSION) && (_COMPILER_VERSION >= 740)
 #      define Q_OUTOFLINE_TEMPLATE inline
 #      pragma set woff 3624,3625,3649 /* turn off some harmless warnings */
@@ -473,6 +644,9 @@
     in which case _BOOL is not defined
         this is the default in 4.2 compatibility mode triggered by -compat=4 */
 #  if __SUNPRO_CC >= 0x500
+#    if __SUNPRO_CC < 0x570
+#      define QT_NO_TEMPLATE_TEMPLATE_PARAMETERS
+#    endif
 #    if !defined(_BOOL)
 #      define Q_NO_BOOL_TYPE
 #    endif
@@ -500,7 +674,11 @@
 #elif defined(Q_OS_HPUX)
 /* __HP_aCC was not defined in first aCC releases */
 #  if defined(__HP_aCC) || __cplusplus >= 199707L
+#    define Q_NO_TEMPLATE_FRIENDS
 #    define Q_CC_HPACC
+#    ifdef QT_ARCH_PARISC
+#      define QT_NO_TEMPLATE_TEMPLATE_PARAMETERS
+#    endif
 #  else
 #    define Q_CC_HP
 #    define Q_NO_BOOL_TYPE
@@ -520,17 +698,19 @@
 #endif
 
 #ifndef Q_CONSTRUCTOR_FUNCTION
-# define Q_CONSTRUCTOR_FUNCTION(AFUNC) \
+# define Q_CONSTRUCTOR_FUNCTION0(AFUNC) \
    static const int AFUNC ## __init_variable__ = AFUNC();
+# define Q_CONSTRUCTOR_FUNCTION(AFUNC) Q_CONSTRUCTOR_FUNCTION0(AFUNC)
 #endif
 
 #ifndef Q_DESTRUCTOR_FUNCTION
-# define Q_DESTRUCTOR_FUNCTION(AFUNC) \
+# define Q_DESTRUCTOR_FUNCTION0(AFUNC) \
     class AFUNC ## __dest_class__ { \
     public: \
        inline AFUNC ## __dest_class__() { } \
        inline ~ AFUNC ## __dest_class__() { AFUNC(); } \
     } AFUNC ## __dest_instance__;
+# define Q_DESTRUCTOR_FUNCTION(AFUNC) Q_DESTRUCTOR_FUNCTION0(AFUNC)
 #endif
 
 #ifndef Q_REQUIRED_RESULT
@@ -541,13 +721,18 @@
 #  endif
 #endif
 
+#ifndef Q_COMPILER_MANGLES_RETURN_TYPE
+#  if defined(Q_CC_MSVC)
+#    define Q_COMPILER_MANGLES_RETURN_TYPE
+#  endif
+#endif
 
 /*
    The window system, must be one of: (Q_WS_x)
 
      MACX     - Mac OS X
      MAC9     - Mac OS 9
-     QWS      - Qtopia Core
+     QWS      - Qt for Embedded Linux
      WIN32    - Windows
      X11      - X Window System
      PM       - unsupported
@@ -564,6 +749,8 @@
 #  if defined(Q_OS_WIN64)
 #    define Q_WS_WIN64
 #  endif
+#elif defined(Q_OS_WINCE)
+#  define Q_WS_WIN32
 #elif defined(Q_OS_OS2)
 #  define Q_WS_PM
 #  error "Qt does not work with OS/2 Presentation Manager or Workplace Shell"
@@ -585,6 +772,9 @@
 #  define Q_WS_WIN
 #endif
 
+QT_BEGIN_HEADER
+QT_BEGIN_NAMESPACE
+
 /*
    Size-dependent types (architechture-dependent byte order)
 
@@ -615,17 +805,17 @@ typedef quint64 qulonglong;
 #ifndef QT_POINTER_SIZE
 #  if defined(Q_OS_WIN64)
 #   define QT_POINTER_SIZE 8
-#  elif defined(Q_OS_WIN32)
+#  elif defined(Q_OS_WIN32) || defined(Q_OS_WINCE)
 #   define QT_POINTER_SIZE 4
 #  endif
 #endif
 
 #define Q_INIT_RESOURCE(name) \
-    do { extern int qInitResources_ ## name ();       \
-        qInitResources_ ## name (); } while (0)
+    do { extern int QT_MANGLE_NAMESPACE(qInitResources_ ## name) ();       \
+        QT_MANGLE_NAMESPACE(qInitResources_ ## name) (); } while (0)
 #define Q_CLEANUP_RESOURCE(name) \
-    do { extern int qCleanupResources_ ## name ();    \
-        qCleanupResources_ ## name (); } while (0)
+    do { extern int QT_MANGLE_NAMESPACE(qCleanupResources_ ## name) ();    \
+        QT_MANGLE_NAMESPACE(qCleanupResources_ ## name) (); } while (0)
 
 #if defined(__cplusplus)
 
@@ -651,10 +841,12 @@ typedef QIntForType<void *>::Type qptrdiff;
    Useful type definitions for Qt
 */
 
+QT_BEGIN_INCLUDE_NAMESPACE
 typedef unsigned char uchar;
 typedef unsigned short ushort;
 typedef unsigned int uint;
 typedef unsigned long ulong;
+QT_END_INCLUDE_NAMESPACE
 
 #if defined(Q_NO_BOOL_TYPE)
 #error "Compiler doesn't support the bool type"
@@ -664,22 +856,13 @@ typedef unsigned long ulong;
    Constant bool values
 */
 
-#ifndef QT_LSB /* the LSB defines TRUE and FALSE for us */
+#ifndef QT_LINUXBASE /* the LSB defines TRUE and FALSE for us */
 #  ifndef TRUE
 #   define TRUE true
 #   define FALSE false
 #  endif
 #endif
 
-#if defined(Q_OS_MAC) && !defined(Q_CC_INTEL)
-#define QT_BEGIN_HEADER extern "C++" {
-#define QT_END_HEADER }
-#else
-#define QT_BEGIN_HEADER
-#define QT_END_HEADER
-#endif
-
-QT_BEGIN_HEADER
 /*
    Proper for-scoping in VC++6 and MIPSpro CC
 */
@@ -706,7 +889,7 @@ QT_BEGIN_HEADER
 */
 #if defined(Q_MOC_RUN)
 #  define Q_DECL_DEPRECATED Q_DECL_DEPRECATED
-#elif defined(Q_CC_GNU) && !defined(Q_CC_INTEL) && (__GNUC__ - 0 > 3 || (__GNUC__ - 0 == 3 && __GNUC_MINOR__ - 0 >= 2))
+#elif (defined(Q_CC_GNU) && !defined(Q_CC_INTEL) && (__GNUC__ - 0 > 3 || (__GNUC__ - 0 == 3 && __GNUC_MINOR__ - 0 >= 2))) || defined(Q_CC_RVCT)
 #  define Q_DECL_DEPRECATED __attribute__ ((__deprecated__))
 #elif defined(Q_CC_MSVC) && (_MSC_VER >= 1300)
 #  define Q_DECL_DEPRECATED __declspec(deprecated)
@@ -803,14 +986,14 @@ QT_BEGIN_HEADER
 #  define QT_ASCII_CAST_WARN_CONSTRUCTOR
 #endif
 
-#ifdef __i386__
+#if defined(__i386__) || defined(_WIN32) || defined(_WIN32_WCE)
 #  if defined(Q_CC_GNU)
 #if !defined(Q_CC_INTEL) && ((100*(__GNUC__ - 0) + 10*(__GNUC_MINOR__ - 0) + __GNUC_PATCHLEVEL__) >= 332)
 #    define QT_FASTCALL __attribute__((regparm(3)))
 #else
 #    define QT_FASTCALL
 #endif
-#  elif defined(Q_CC_MSVC)
+#  elif defined(Q_CC_MSVC) && (_MSC_VER > 1300 || defined(Q_CC_INTEL))
 #    define QT_FASTCALL __fastcall
 #  else
 #     define QT_FASTCALL
@@ -821,13 +1004,13 @@ QT_BEGIN_HEADER
 
 typedef int QNoImplicitBoolCast;
 
-#if defined(QT_ARCH_ARM) || (defined(QT_ARCH_MIPS) && !defined(Q_OS_IRIX))
+#if defined(QT_ARCH_ARM) || defined(QT_ARCH_ARMV6) || defined(QT_ARCH_AVR32) || (defined(QT_ARCH_MIPS) && (defined(Q_WS_QWS) || defined(Q_OS_WINCE))) || defined(QT_ARCH_SH) || defined(QT_ARCH_SH4A)
 #define QT_NO_FPU
 #endif
 
 #if defined(QT_COORD_TYPE)
 typedef QT_COORD_TYPE qreal;
-#elif defined(QT_NO_FPU)
+#elif defined(QT_NO_FPU) || defined(QT_ARCH_ARM) || defined(QT_ARCH_WINDOWSCE)
 typedef float qreal;
 #else
 typedef double qreal;
@@ -885,26 +1068,6 @@ typedef unsigned long Q_ULONG;      /* word up to 64 bit unsigned */
 
 class QDataStream;
 
-#ifdef Q_OS_DARWIN
-#  ifdef MAC_OS_X_VERSION_MIN_REQUIRED
-#    undef MAC_OS_X_VERSION_MIN_REQUIRED
-#  endif
-#  define MAC_OS_X_VERSION_MIN_REQUIRED MAC_OS_X_VERSION_10_3
-#  include <AvailabilityMacros.h>
-#  if !defined(MAC_OS_X_VERSION_10_3)
-#     define MAC_OS_X_VERSION_10_3 MAC_OS_X_VERSION_10_2 + 1
-#  endif
-#  if !defined(MAC_OS_X_VERSION_10_4)
-#       define MAC_OS_X_VERSION_10_4 MAC_OS_X_VERSION_10_3 + 1
-#  endif
-#  if !defined(MAC_OS_X_VERSION_10_5)
-#       define MAC_OS_X_VERSION_10_5 MAC_OS_X_VERSION_10_4 + 1
-#  endif
-#  if (MAC_OS_X_VERSION_MAX_ALLOWED > MAC_OS_X_VERSION_10_5)
-#    error "This version of Mac OS X is unsupported"
-#  endif
-#endif
-
 #ifndef QT_BUILD_KEY
 #define QT_BUILD_KEY "unspecified"
 #endif
@@ -921,6 +1084,8 @@ class QDataStream;
 
 # include <QtCore/qfeatures.h>
 
+#define QT_SUPPORTS(FEATURE) (!defined(QT_NO_##FEATURE))
+
 #ifndef Q_DECL_EXPORT
 #  ifdef Q_OS_WIN
 #    define Q_DECL_EXPORT __declspec(dllexport)
@@ -986,11 +1151,21 @@ class QDataStream;
 #    else
 #      define Q_XML_EXPORT Q_DECL_IMPORT
 #    endif
+#    if defined(QT_BUILD_XMLPATTERNS_LIB)
+#      define Q_XMLPATTERNS_EXPORT Q_DECL_EXPORT
+#    else
+#      define Q_XMLPATTERNS_EXPORT Q_DECL_IMPORT
+#    endif
 #    if defined(QT_BUILD_SCRIPT_LIB)
 #      define Q_SCRIPT_EXPORT Q_DECL_EXPORT
 #    else
 #      define Q_SCRIPT_EXPORT Q_DECL_IMPORT
 #    endif
+#    if defined(QT_BUILD_SCRIPTTOOLS_LIB)
+#      define Q_SCRIPTTOOLS_EXPORT Q_DECL_EXPORT
+#    else
+#      define Q_SCRIPTTOOLS_EXPORT Q_DECL_IMPORT
+#    endif
 #    if defined(QT_BUILD_CANVAS_LIB)
 #      define Q_CANVAS_EXPORT Q_DECL_EXPORT
 #    else
@@ -1011,7 +1186,9 @@ class QDataStream;
 #    define Q_CANVAS_EXPORT Q_DECL_IMPORT
 #    define Q_OPENGL_EXPORT Q_DECL_IMPORT
 #    define Q_XML_EXPORT Q_DECL_IMPORT
+#    define Q_XMLPATTERNS_EXPORT Q_DECL_IMPORT
 #    define Q_SCRIPT_EXPORT Q_DECL_IMPORT
+#    define Q_SCRIPTTOOLS_EXPORT Q_DECL_IMPORT
 #    define Q_COMPAT_EXPORT Q_DECL_IMPORT
 #    define Q_TEMPLATEDLL
 #  endif
@@ -1034,7 +1211,9 @@ class QDataStream;
 #    define Q_SVG_EXPORT Q_DECL_EXPORT
 #    define Q_OPENGL_EXPORT Q_DECL_EXPORT
 #    define Q_XML_EXPORT Q_DECL_EXPORT
+#    define Q_XMLPATTERNS_EXPORT Q_DECL_EXPORT
 #    define Q_SCRIPT_EXPORT Q_DECL_EXPORT
+#    define Q_SCRIPTTOOLS_EXPORT Q_DECL_EXPORT
 #    define Q_COMPAT_EXPORT Q_DECL_EXPORT
 #  else
 #    define Q_CORE_EXPORT
@@ -1044,7 +1223,9 @@ class QDataStream;
 #    define Q_SVG_EXPORT
 #    define Q_OPENGL_EXPORT
 #    define Q_XML_EXPORT
+#    define Q_XMLPATTERNS_EXPORT
 #    define Q_SCRIPT_EXPORT
+#    define Q_SCRIPTTOOLS_EXPORT
 #    define Q_COMPAT_EXPORT
 #  endif
 #endif
@@ -1069,7 +1250,7 @@ class QDataStream;
 
 /*
    No, this is not an evil backdoor. QT_BUILD_INTERNAL just exports more symbols
-   for Trolltech's internal unit tests. If you want slower loading times and more
+   for Qt's internal unit tests. If you want slower loading times and more
    symbols that can vanish from version to version, feel free to define QT_BUILD_INTERNAL.
 */
 #if defined(QT_BUILD_INTERNAL) && defined(Q_OS_WIN) && defined(QT_MAKEDLL)
@@ -1118,7 +1299,7 @@ public:
 #else
 #  error "Qt not configured correctly, please run configure"
 #endif
-#ifdef Q_WS_WIN
+#if defined(Q_WS_WIN) || defined(Q_OS_CYGWIN)
     enum WinVersion {
         WV_32s      = 0x0001,
         WV_95       = 0x0002,
@@ -1126,18 +1307,32 @@ public:
         WV_Me       = 0x0004,
         WV_DOS_based= 0x000f,
 
+        /* codenames */
         WV_NT       = 0x0010,
         WV_2000     = 0x0020,
         WV_XP       = 0x0030,
         WV_2003     = 0x0040,
         WV_VISTA    = 0x0080,
+        WV_WINDOWS7 = 0x0090,
         WV_NT_based = 0x00f0,
 
+        /* version numbers */
+        WV_4_0      = WV_NT,
+        WV_5_0      = WV_2000,
+        WV_5_1      = WV_XP,
+        WV_5_2      = WV_2003,
+        WV_6_0      = WV_VISTA,
+        WV_6_1      = WV_WINDOWS7,
+
         WV_CE       = 0x0100,
         WV_CENET    = 0x0200,
+        WV_CE_5     = 0x0300,
+        WV_CE_6     = 0x0400,
         WV_CE_based = 0x0f00
     };
     static const WinVersion WindowsVersion;
+    static WinVersion windowsVersion();
+
 #endif
 #ifdef Q_OS_MAC
     enum MacVersion {
@@ -1151,6 +1346,7 @@ public:
         MV_10_3 = 0x0005,
         MV_10_4 = 0x0006,
         MV_10_5 = 0x0007,
+        MV_10_6 = 0x0008,
 
         /* codenames */
         MV_CHEETAH = MV_10_0,
@@ -1158,7 +1354,8 @@ public:
         MV_JAGUAR = MV_10_2,
         MV_PANTHER = MV_10_3,
         MV_TIGER = MV_10_4,
-        MV_LEOPARD = MV_10_5
+        MV_LEOPARD = MV_10_5,
+        MV_SNOWLEOPARD = MV_10_6
     };
     static const MacVersion MacintoshVersion;
 #endif
@@ -1180,18 +1377,19 @@ inline QT3_SUPPORT bool qSysInfo(int *wordSize, bool *bigEndian)
 }
 #endif
 
-#if defined(Q_WS_WIN)
+#if defined(Q_WS_WIN) || defined(Q_OS_CYGWIN)
 #if defined(QT3_SUPPORT)
 inline QT3_SUPPORT bool qt_winUnicode() { return !(QSysInfo::WindowsVersion & QSysInfo::WV_DOS_based); }
 inline QT3_SUPPORT int qWinVersion() { return QSysInfo::WindowsVersion; }
 #endif
 
-#ifdef Q_OS_TEMP
+#ifdef Q_OS_WINCE
 #define QT_WA(uni, ansi) uni
 #define QT_WA_INLINE(uni, ansi) (uni)
 #elif defined(UNICODE)
-#define QT_WA(uni, ansi) if (!(QSysInfo::WindowsVersion& QSysInfo::WV_DOS_based)) { uni } else { ansi }
-#define QT_WA_INLINE(uni, ansi) (!(QSysInfo::WindowsVersion& QSysInfo::WV_DOS_based) ? uni : ansi)
+#define QT_WA(uni, ansi) if (!(QSysInfo::windowsVersion() & QSysInfo::WV_DOS_based)) { uni } else { ansi }
+
+#define QT_WA_INLINE(uni, ansi) (!(QSysInfo::windowsVersion() & QSysInfo::WV_DOS_based) ? uni : ansi)
 #else
 #define QT_WA(uni, ansi) ansi
 #define QT_WA_INLINE(uni, ansi) ansi
@@ -1287,8 +1485,9 @@ inline QNoDebug qDebug();
 #ifdef QT_NO_DEBUG_OUTPUT
 #  define qDebug QT_NO_QDEBUG_MACRO
 #endif
+#define QT_NO_QWARNING_MACRO if(1); else qWarning
 #ifdef QT_NO_WARNING_OUTPUT
-#  define qWarning if(1); else qWarning
+#  define qWarning QT_NO_QWARNING_MACRO
 #endif
 
 
@@ -1298,19 +1497,23 @@ Q_CORE_EXPORT void qt_assert(const char *assertion, const char *file, int line);
 
 #if !defined(Q_ASSERT)
 #  ifndef QT_NO_DEBUG
-#    define Q_ASSERT(cond) do {if(!(cond))qt_assert(#cond,__FILE__,__LINE__);} while (0)
+#    define Q_ASSERT(cond) ((!(cond)) ? qt_assert(#cond,__FILE__,__LINE__) : qt_noop())
 #  else
-#    define Q_ASSERT(cond) do{}while(0)
+#    define Q_ASSERT(cond) qt_noop()
 #  endif
 #endif
 
+#if defined(QT_NO_DEBUG) && !defined(QT_PAINT_DEBUG)
+#define QT_NO_PAINT_DEBUG
+#endif
+
 Q_CORE_EXPORT void qt_assert_x(const char *where, const char *what, const char *file, int line);
 
 #if !defined(Q_ASSERT_X)
 #  ifndef QT_NO_DEBUG
-#    define Q_ASSERT_X(cond, where, what) do {if(!(cond))qt_assert_x(where, what,__FILE__,__LINE__);} while (0)
+#    define Q_ASSERT_X(cond, where, what) ((!(cond)) ? qt_assert_x(where, what,__FILE__,__LINE__) : qt_noop())
 #  else
-#    define Q_ASSERT_X(cond, where, what) do{}while(0)
+#    define Q_ASSERT_X(cond, where, what) qt_noop()
 #  endif
 #endif
 
@@ -1388,17 +1591,29 @@ public:
         return global_##NAME.pointer;                            \
     }
 
+#define Q_GLOBAL_STATIC_WITH_INITIALIZER(TYPE, NAME, INITIALIZER) \
+    static TYPE *NAME()                                           \
+    {                                                             \
+        static TYPE this_##NAME;                                  \
+        static QGlobalStatic<TYPE > global_##NAME(0);             \
+        if (!global_##NAME.pointer) {                             \
+            TYPE *x = global_##NAME.pointer = &this_##NAME;       \
+            INITIALIZER;                                          \
+        }                                                         \
+        return global_##NAME.pointer;                             \
+    }
+
 #else
 
 // forward declaration, since qatomic.h needs qglobal.h
-template <typename T> struct QBasicAtomicPointer;
+template <typename T> class QBasicAtomicPointer;
 
 // POD for Q_GLOBAL_STATIC
 template <typename T>
 class QGlobalStatic
 {
 public:
-    T *pointer;
+    QBasicAtomicPointer<T> pointer;
     bool destroyed;
 };
 
@@ -1420,14 +1635,8 @@ public:
     }
 };
 
-#if (defined Q_OS_HPUX && defined Q_CC_HPACC && !defined __ia64)
-// aCC 3.x bug
-#  define Q_GLOBAL_STATIC_INIT(TYPE, NAME)                              \
-    static QGlobalStatic<TYPE > this_##NAME
-#else
-#  define Q_GLOBAL_STATIC_INIT(TYPE, NAME)                              \
-    static QGlobalStatic<TYPE > this_##NAME = { 0, false }
-#endif
+#define Q_GLOBAL_STATIC_INIT(TYPE, NAME)                              \
+    static QGlobalStatic<TYPE > this_##NAME = { Q_BASIC_ATOMIC_INITIALIZER(0), false }
 
 #define Q_GLOBAL_STATIC(TYPE, NAME)                                     \
     Q_GLOBAL_STATIC_INIT(TYPE, NAME);                                   \
@@ -1435,7 +1644,7 @@ public:
     {                                                                   \
         if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
             TYPE *x = new TYPE;                                         \
-            if (!q_atomic_test_and_set_ptr(&this_##NAME.pointer, 0, x)) \
+            if (!this_##NAME.pointer.testAndSetOrdered(0, x))           \
                 delete x;                                               \
             else                                                        \
                 static QGlobalStaticDeleter<TYPE > cleanup(this_##NAME); \
@@ -1449,7 +1658,22 @@ public:
     {                                                                   \
         if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
             TYPE *x = new TYPE ARGS;                                    \
-            if (!q_atomic_test_and_set_ptr(&this_##NAME.pointer, 0, x)) \
+            if (!this_##NAME.pointer.testAndSetOrdered(0, x))           \
+                delete x;                                               \
+            else                                                        \
+                static QGlobalStaticDeleter<TYPE > cleanup(this_##NAME); \
+        }                                                               \
+        return this_##NAME.pointer;                                     \
+    }
+
+#define Q_GLOBAL_STATIC_WITH_INITIALIZER(TYPE, NAME, INITIALIZER)       \
+    Q_GLOBAL_STATIC_INIT(TYPE, NAME);                                   \
+    static TYPE *NAME()                                                 \
+    {                                                                   \
+        if (!this_##NAME.pointer && !this_##NAME.destroyed) {           \
+            TYPE *x = new TYPE;                                         \
+            INITIALIZER;                                                \
+            if (!this_##NAME.pointer.testAndSetOrdered(0, x))           \
                 delete x;                                               \
             else                                                        \
                 static QGlobalStaticDeleter<TYPE > cleanup(this_##NAME); \
@@ -1478,12 +1702,12 @@ inline bool operator!=(QBool b1, QBool b2) { return !b1 != !b2; }
 
 static inline bool qFuzzyCompare(double p1, double p2)
 {
-    return qAbs(p1 - p2) < 0.00000000001;
+    return (qAbs(p1 - p2) <= 0.000000000001 * qMin(qAbs(p1), qAbs(p2)));
 }
 
 static inline bool qFuzzyCompare(float p1, float p2)
 {
-    return qAbs(p1 - p2) < 0.000001;
+    return (qAbs(p1 - p2) <= 0.00001f * qMin(qAbs(p1), qAbs(p2)));
 }
 
 /*
@@ -1722,6 +1946,10 @@ Q_CORE_EXPORT void *qMemSet(void *dest, int c, size_t n);
 #    pragma warning(disable: 4231) /* nonstandard extension used : 'extern' before template explicit instantiation */
 #    pragma warning(disable: 4710) /* function not inlined */
 #    pragma warning(disable: 4530) /* C++ exception handler used, but unwind semantics are not enabled. Specify -GX */
+#    if _MSC_VER < 1300
+#      pragma warning(disable: 4284) /* return type for 'type1::operator ->' is 'type2 *' */
+                                     /* (ie; not a UDT or reference to a UDT.  Will produce errors if applied using infix notation) */
+#    endif
 #  elif defined(Q_CC_BOR)
 #    pragma option -w-inl
 #    pragma option -w-aus
@@ -1743,6 +1971,16 @@ public:
 
 inline QFlag::QFlag(int ai) : i(ai) {}
 
+class Q_CORE_EXPORT QIncompatibleFlag
+{
+    int i;
+public:
+    inline explicit QIncompatibleFlag(int i);
+    inline operator int() const { return i; }
+};
+
+inline QIncompatibleFlag::QIncompatibleFlag(int ai) : i(ai) {}
+
 
 #ifndef Q_NO_TYPESAFE_FLAGS
 
@@ -1779,21 +2017,26 @@ public:
 
     inline bool operator!() const { return !i; }
 
-    inline bool testFlag(Enum f) const { return i & f; }
-
-private:
-#if QT_VERSION >= 0x050000 && !defined(Q_NO_DECLARED_NOT_DEFINED)
-    explicit QFlags(bool);
-#endif
+    inline bool testFlag(Enum f) const { return (i & f) == f && (f != 0 || i == f ); }
 };
 
 #define Q_DECLARE_FLAGS(Flags, Enum)\
 typedef QFlags<Enum> Flags;
+
+#if defined Q_CC_MSVC && _MSC_VER < 1300
+# define Q_DECLARE_INCOMPATIBLE_FLAGS(Flags)
+#else
+# define Q_DECLARE_INCOMPATIBLE_FLAGS(Flags) \
+inline QIncompatibleFlag operator|(Flags::enum_type f1, int f2) \
+{ return QIncompatibleFlag(int(f1) | f2); }
+#endif
+
 #define Q_DECLARE_OPERATORS_FOR_FLAGS(Flags) \
 inline QFlags<Flags::enum_type> operator|(Flags::enum_type f1, Flags::enum_type f2) \
 { return QFlags<Flags::enum_type>(f1) | f2; } \
 inline QFlags<Flags::enum_type> operator|(Flags::enum_type f1, QFlags<Flags::enum_type> f2) \
-{ return f2 | f1; }
+{ return f2 | f1; } Q_DECLARE_INCOMPATIBLE_FLAGS(Flags)
+
 
 #else /* Q_NO_TYPESAFE_FLAGS */
 
@@ -1891,7 +2134,12 @@ inline const QForeachContainer<T> *qForeachContainer(const QForeachContainerBase
     inline const Class##Private* d_func() const { return reinterpret_cast<const Class##Private *>(d_ptr); } \
     friend class Class##Private;
 
-#define Q_DECLARE_PUBLIC(Class) \
+#define Q_DECLARE_PRIVATE_D(Dptr, Class) \
+    inline Class##Private* d_func() { return reinterpret_cast<Class##Private *>(Dptr); } \
+    inline const Class##Private* d_func() const { return reinterpret_cast<const Class##Private *>(Dptr); } \
+    friend class Class##Private;
+
+#define Q_DECLARE_PUBLIC(Class)                                    \
     inline Class* q_func() { return static_cast<Class *>(q_ptr); } \
     inline const Class* q_func() const { return static_cast<const Class *>(q_ptr); } \
     friend class Class;
@@ -1900,9 +2148,26 @@ inline const QForeachContainer<T> *qForeachContainer(const QForeachContainerBase
 #define Q_Q(Class) Class * const q = q_func()
 
 #define QT_TR_NOOP(x) (x)
+#define QT_TR_NOOP_UTF8(x) (x)
 #define QT_TRANSLATE_NOOP(scope, x) (x)
+#define QT_TRANSLATE_NOOP_UTF8(scope, x) (x)
+#define QT_TRANSLATE_NOOP3(scope, x, comment) {x, comment}
+#define QT_TRANSLATE_NOOP3_UTF8(scope, x, comment) {x, comment}
 #define QDOC_PROPERTY(text)
 
+/*
+   When RTTI is not available, define this macro to force any uses of
+   dynamic_cast to cause a compile failure.
+*/
+
+#ifdef QT_NO_DYNAMIC_CAST
+#  define dynamic_cast QT_PREPEND_NAMESPACE(qt_dynamic_cast_check)
+
+  template<typename T, typename X>
+  T qt_dynamic_cast_check(X, T* = 0)
+  { return T::dynamic_cast_will_always_fail_because_rtti_is_disabled; }
+#endif
+
 /*
    Some classes do not permit copies to be made of an object. These
    classes contains a private copy constructor and assignment
@@ -1910,15 +2175,16 @@ inline const QForeachContainer<T> *qForeachContainer(const QForeachContainerBase
 */
 
 #if !defined(Q_NO_DECLARED_NOT_DEFINED) || !defined(QT_MAKEDLL)
- #define Q_DISABLE_COPY(Class) \
+# define Q_DISABLE_COPY(Class) \
      Class(const Class &); \
      Class &operator=(const Class &);
 #else
- #define Q_DISABLE_COPY(Class)
+# define Q_DISABLE_COPY(Class)
 #endif
 
 class QByteArray;
 Q_CORE_EXPORT QByteArray qgetenv(const char *varName);
+Q_CORE_EXPORT bool qputenv(const char *varName, const QByteArray& value);
 
 inline int qIntCast(double f) { return int(f); }
 inline int qIntCast(float f) { return int(f); }
@@ -1956,41 +2222,56 @@ QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
 */
 
 /* Qt modules */
-#define QT_MODULE_CORE                  0x001
-#define QT_MODULE_GUI                   0x002
-#define QT_MODULE_NETWORK               0x004
-#define QT_MODULE_OPENGL                0x008
-#define QT_MODULE_SQL                   0x010
-#define QT_MODULE_XML                   0x020
-#define QT_MODULE_QT3SUPPORTLIGHT       0x040
-#define QT_MODULE_QT3SUPPORT            0x080
-#define QT_MODULE_SVG                   0x100
-#define QT_MODULE_ACTIVEQT              0x200
-#define QT_MODULE_GRAPHICSVIEW          0x400
-#define QT_MODULE_SCRIPT                0x800
+#define QT_MODULE_CORE                 0x00001
+#define QT_MODULE_GUI                  0x00002
+#define QT_MODULE_NETWORK              0x00004
+#define QT_MODULE_OPENGL               0x00008
+#define QT_MODULE_SQL                  0x00010
+#define QT_MODULE_XML                  0x00020
+#define QT_MODULE_QT3SUPPORTLIGHT      0x00040
+#define QT_MODULE_QT3SUPPORT           0x00080
+#define QT_MODULE_SVG                  0x00100
+#define QT_MODULE_ACTIVEQT             0x00200
+#define QT_MODULE_GRAPHICSVIEW         0x00400
+#define QT_MODULE_SCRIPT               0x00800
+#define QT_MODULE_XMLPATTERNS          0x01000
+#define QT_MODULE_HELP                 0x02000
+#define QT_MODULE_TEST                 0x04000
+#define QT_MODULE_DBUS                 0x08000
+#define QT_MODULE_SCRIPTTOOLS          0x10000
 
 /* Qt editions */
 #define QT_EDITION_CONSOLE      (QT_MODULE_CORE \
                                  | QT_MODULE_NETWORK \
                                  | QT_MODULE_SQL \
                                  | QT_MODULE_SCRIPT \
-                                 | QT_MODULE_XML)
+                                 | QT_MODULE_XML \
+                                 | QT_MODULE_XMLPATTERNS \
+                                 | QT_MODULE_TEST \
+                                 | QT_MODULE_DBUS)
 #define QT_EDITION_DESKTOPLIGHT (QT_MODULE_CORE \
                                  | QT_MODULE_GUI \
-                                 | QT_MODULE_QT3SUPPORTLIGHT)
+                                 | QT_MODULE_QT3SUPPORTLIGHT \
+                                 | QT_MODULE_TEST \
+                                 | QT_MODULE_DBUS)
 #define QT_EDITION_OPENSOURCE   (QT_MODULE_CORE \
                                  | QT_MODULE_GUI \
                                  | QT_MODULE_NETWORK \
                                  | QT_MODULE_OPENGL \
                                  | QT_MODULE_SQL \
                                  | QT_MODULE_XML \
+                                 | QT_MODULE_XMLPATTERNS \
                                  | QT_MODULE_SCRIPT \
+                                 | QT_MODULE_SCRIPTTOOLS \
                                  | QT_MODULE_QT3SUPPORTLIGHT \
                                  | QT_MODULE_QT3SUPPORT \
                                  | QT_MODULE_SVG \
-                                 | QT_MODULE_GRAPHICSVIEW)
-#define QT_EDITION_DESKTOP      (QT_EDITION_OPENSOURCE \
+                                 | QT_MODULE_GRAPHICSVIEW \
+                                 | QT_MODULE_HELP \
+                                 | QT_MODULE_TEST \
+                                 | QT_MODULE_DBUS \
                                  | QT_MODULE_ACTIVEQT)
+#define QT_EDITION_DESKTOP      (QT_EDITION_OPENSOURCE)
 #define QT_EDITION_UNIVERSAL    QT_EDITION_DESKTOP
 #define QT_EDITION_ACADEMIC     QT_EDITION_DESKTOP
 #define QT_EDITION_EDUCATIONAL  QT_EDITION_DESKTOP
@@ -2026,9 +2307,18 @@ QT_LICENSED_MODULE(Sql)
 #if (QT_EDITION & QT_MODULE_XML)
 QT_LICENSED_MODULE(Xml)
 #endif
-#if (QT_EDITION & QT_MODULE_SCRIPT)
+#if (QT_EDITION & QT_MODULE_XMLPATTERNS)
+QT_LICENSED_MODULE(XmlPatterns)
+#endif
+#if (QT_EDITION & QT_MODULE_HELP)
+QT_LICENSED_MODULE(Help)
+#endif
+#if (QT_EDITION & QT_MODULE_SCRIPT) || defined(QT_BUILD_QMAKE)
 QT_LICENSED_MODULE(Script)
 #endif
+#if (QT_EDITION & QT_MODULE_SCRIPTTOOLS)
+QT_LICENSED_MODULE(ScriptTools)
+#endif
 #if (QT_EDITION & QT_MODULE_QT3SUPPORTLIGHT)
 QT_LICENSED_MODULE(Qt3SupportLight)
 #endif
@@ -2041,10 +2331,47 @@ QT_LICENSED_MODULE(Svg)
 #if (QT_EDITION & QT_MODULE_ACTIVEQT)
 QT_LICENSED_MODULE(ActiveQt)
 #endif
+#if (QT_EDITION & QT_MODULE_TEST)
+QT_LICENSED_MODULE(Test)
+#endif
+#if (QT_EDITION & QT_MODULE_DBUS)
+QT_LICENSED_MODULE(DBus)
+#endif
 
 #define QT_MODULE(x) \
     typedef QtValidLicenseFor##x##Module Qt##x##Module;
 
+#ifdef QT_NO_CONCURRENT
+#  define QT_NO_QFUTURE
+#endif
+
+/*
+    Turn off certain features for compilers that have problems parsing
+    the code.
+*/
+#if (defined(Q_CC_HPACC) && defined(QT_ARCH_PARISC)) \
+    || defined(Q_CC_MIPS) \
+    || defined(Q_CC_XLC)
+// HP aCC A.03.*, MIPSpro, and xlC cannot handle
+// the template function declarations for the QtConcurrent functions
+#  define QT_NO_QFUTURE
+#  define QT_NO_CONCURRENT
+#endif
+
+// MSVC 6.0, MSVC .NET 2002, and old versions of Sun CC can`t handle the map(), etc templates,
+// but the QFuture class compiles.
+#if (defined(Q_CC_MSVC) && _MSC_VER <= 1300) || (defined (__SUNPRO_CC) && __SUNPRO_CC <= 0x590)
+#  define QT_NO_CONCURRENT
+#endif
+
+// Mingw uses a gcc 3 version which has problems with some of the
+// map/filter overloads. So does IRIX and Solaris.
+#if (defined(Q_OS_IRIX) || defined(Q_CC_MINGW) || defined (Q_OS_SOLARIS)) && (__GNUC__ < 4)
+#  define QT_NO_CONCURRENT_MAP
+#  define QT_NO_CONCURRENT_FILTER
+#endif
+
+QT_END_NAMESPACE
 QT_END_HEADER
 
 #endif /* __cplusplus */
