@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -28,14 +46,19 @@
 #include <QtCore/qchar.h>
 #include <QtCore/qiterator.h>
 #include <QtCore/qlist.h>
+#include <QtCore/qpair.h>
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 #undef QT_QHASH_DEBUG
 QT_MODULE(Core)
 
+class QBitArray;
 class QByteArray;
 class QString;
+class QStringRef;
 
 inline uint qHash(char key) { return uint(key); }
 inline uint qHash(uchar key) { return uint(key); }
@@ -65,6 +88,8 @@ inline uint qHash(qint64 key) { return qHash(quint64(key)); }
 inline uint qHash(QChar key) { return qHash(key.unicode()); }
 Q_CORE_EXPORT uint qHash(const QByteArray &key);
 Q_CORE_EXPORT uint qHash(const QString &key);
+Q_CORE_EXPORT uint qHash(const QStringRef &key);
+Q_CORE_EXPORT uint qHash(const QBitArray &key);
 
 #if defined(Q_CC_MSVC)
 #pragma warning( push )
@@ -72,15 +97,19 @@ Q_CORE_EXPORT uint qHash(const QString &key);
 #endif
 template <class T> inline uint qHash(const T *key)
 {
-    if (sizeof(const T *) > sizeof(uint))
-        return qHash(reinterpret_cast<quint64>(key));
-    else
-        return uint(reinterpret_cast<ulong>(key));
+    return qHash(reinterpret_cast<quintptr>(key));
 }
 #if defined(Q_CC_MSVC)
 #pragma warning( pop )
 #endif
 
+template <typename T1, typename T2> inline uint qHash(const QPair<T1, T2> &key)
+{
+    uint h1 = qHash(key.first);
+    uint h2 = qHash(key.second);
+    return ((h1 << 16) | (h1 >> 16)) ^ h2;
+}
+
 struct Q_CORE_EXPORT QHashData
 {
     struct Node {
@@ -90,7 +119,7 @@ struct Q_CORE_EXPORT QHashData
 
     Node *fakeNext;
     Node **buckets;
-    QBasicAtomic ref;
+    QBasicAtomicInt ref;
     int size;
     int nodeSize;
     short userNumBits;
@@ -102,6 +131,7 @@ struct Q_CORE_EXPORT QHashData
     void freeNode(void *node);
     QHashData *detach_helper(void (*node_duplicate)(Node *, void *), int nodeSize);
     void mightGrow();
+    bool willGrow();
     void hasShrunk();
     void rehash(int hint);
     void destroyAndFree();
@@ -116,10 +146,20 @@ struct Q_CORE_EXPORT QHashData
     static QHashData shared_null;
 };
 
-inline void QHashData::mightGrow()
-{
+inline void QHashData::mightGrow() // ### Qt 5: eliminate
+{ 
     if (size >= numBuckets)
         rehash(numBits + 1);
+}  
+
+inline bool QHashData::willGrow()
+{
+    if (size >= numBuckets) {
+        rehash(numBits + 1);
+        return true;
+    } else {
+        return false;
+    }
 }
 
 inline void QHashData::hasShrunk()
@@ -249,6 +289,7 @@ public:
 
     bool contains(const Key &key) const;
     const Key key(const T &value) const;
+    const Key key(const T &value, const Key &defaultKey) const;
     const T value(const Key &key) const;
     const T value(const Key &key, const T &defaultValue) const;
     T &operator[](const Key &key);
@@ -265,6 +306,7 @@ public:
 
     class iterator
     {
+        friend class const_iterator;
         QHashData::Node *i;
 
     public:
@@ -317,9 +359,9 @@ public:
     public:
 #endif
         inline bool operator==(const const_iterator &o) const
-            { return i == reinterpret_cast<const iterator &>(o).i; }
+            { return i == o.i; }
         inline bool operator!=(const const_iterator &o) const
-            { return i != reinterpret_cast<const iterator &>(o).i; }
+            { return i != o.i; }
 
     private:
         // ### Qt 5: remove
@@ -329,6 +371,7 @@ public:
 
     class const_iterator
     {
+        friend class iterator;
         QHashData::Node *i;
 
     public:
@@ -348,7 +391,7 @@ public:
 #else
         inline const_iterator(const iterator &o)
 #endif
-        { i = reinterpret_cast<const const_iterator &>(o).i; }
+        { i = o.i; }
 
         inline const Key &key() const { return concrete(i)->key; }
         inline const T &value() const { return concrete(i)->value; }
@@ -520,20 +563,19 @@ Q_OUTOFLINE_TEMPLATE void QHash<Key, T>::detach_helper()
 {
     QHashData *x = d->detach_helper(duplicateNode,
         QTypeInfo<T>::isDummy ? sizeof(DummyNode) : sizeof(Node));
-    x = qAtomicSetPtr(&d, x);
-    if (!x->ref.deref())
-        freeData(x);
+    if (!d->ref.deref())
+        freeData(d);
+    d = x;
 }
 
 template <class Key, class T>
 Q_INLINE_TEMPLATE QHash<Key, T> &QHash<Key, T>::operator=(const QHash<Key, T> &other)
 {
     if (d != other.d) {
-        QHashData *x = other.d;
-        x->ref.ref();
-        x = qAtomicSetPtr(&d, x);
-        if (!x->ref.deref())
-            freeData(x);
+        other.d->ref.ref();
+        if (!d->ref.deref())
+            freeData(d);
+        d = other.d;
         if (!d->sharable)
             detach_helper();
     }
@@ -543,8 +585,8 @@ Q_INLINE_TEMPLATE QHash<Key, T> &QHash<Key, T>::operator=(const QHash<Key, T> &o
 template <class Key, class T>
 Q_INLINE_TEMPLATE const T QHash<Key, T>::value(const Key &akey) const
 {
-    Node *node = *findNode(akey);
-    if (node == e) {
+    Node *node;
+    if (d->size == 0 || (node = *findNode(akey)) == e) {
         return T();
     } else {
         return node->value;
@@ -554,8 +596,8 @@ Q_INLINE_TEMPLATE const T QHash<Key, T>::value(const Key &akey) const
 template <class Key, class T>
 Q_INLINE_TEMPLATE const T QHash<Key, T>::value(const Key &akey, const T &adefaultValue) const
 {
-    Node *node = *findNode(akey);
-    if (node == e) {
+    Node *node;
+    if (d->size == 0 || (node = *findNode(akey)) == e) {
         return adefaultValue;
     } else {
         return node->value;
@@ -608,6 +650,12 @@ Q_OUTOFLINE_TEMPLATE QList<Key> QHash<Key, T>::keys(const T &avalue) const
 
 template <class Key, class T>
 Q_OUTOFLINE_TEMPLATE const Key QHash<Key, T>::key(const T &avalue) const
+{
+    return key(avalue, Key());
+}
+
+template <class Key, class T>
+Q_OUTOFLINE_TEMPLATE const Key QHash<Key, T>::key(const T &avalue, const Key &defaultValue) const
 {
     const_iterator i = begin();
     while (i != end()) {
@@ -616,7 +664,7 @@ Q_OUTOFLINE_TEMPLATE const Key QHash<Key, T>::key(const T &avalue) const
         ++i;
     }
 
-    return Key();
+    return defaultValue;
 }
 
 template <class Key, class T>
@@ -667,12 +715,14 @@ template <class Key, class T>
 Q_INLINE_TEMPLATE T &QHash<Key, T>::operator[](const Key &akey)
 {
     detach();
-    d->mightGrow();
 
     uint h;
     Node **node = findNode(akey, &h);
-    if (*node == e)
+    if (*node == e) {
+        if (d->willGrow())
+            node = findNode(akey, &h);
         return createNode(h, akey, T(), node)->value;
+    }
     return (*node)->value;
 }
 
@@ -681,12 +731,14 @@ Q_INLINE_TEMPLATE typename QHash<Key, T>::iterator QHash<Key, T>::insert(const K
                                                                          const T &avalue)
 {
     detach();
-    d->mightGrow();
 
     uint h;
     Node **node = findNode(akey, &h);
-    if (*node == e)
+    if (*node == e) {
+        if (d->willGrow())
+            node = findNode(akey, &h);
         return iterator(createNode(h, akey, avalue, node));
+    }
 
     if (!QTypeInfo<T>::isDummy)
         (*node)->value = avalue;
@@ -698,7 +750,7 @@ Q_INLINE_TEMPLATE typename QHash<Key, T>::iterator QHash<Key, T>::insertMulti(co
                                                                               const T &avalue)
 {
     detach();
-    d->mightGrow();
+    d->willGrow();
 
     uint h;
     Node **nextNode = findNode(akey, &h);
@@ -848,31 +900,115 @@ public:
     QMultiHash() {}
     QMultiHash(const QHash<Key, T> &other) : QHash<Key, T>(other) {}
 
-    inline typename QHash<Key, T>::iterator replace(const Key &key, const T &value);
-    inline typename QHash<Key, T>::iterator insert(const Key &key, const T &value);
+    inline typename QHash<Key, T>::iterator replace(const Key &key, const T &value)
+    { return QHash<Key, T>::insert(key, value); }
+
+    inline typename QHash<Key, T>::iterator insert(const Key &key, const T &value)
+    { return QHash<Key, T>::insertMulti(key, value); }
 
     inline QMultiHash &operator+=(const QMultiHash &other)
     { unite(other); return *this; }
     inline QMultiHash operator+(const QMultiHash &other) const
     { QMultiHash result = *this; result += other; return result; }
 
+#ifndef Q_NO_USING_KEYWORD
+    using QHash<Key, T>::contains;
+    using QHash<Key, T>::remove;
+    using QHash<Key, T>::count;
+    using QHash<Key, T>::find;
+    using QHash<Key, T>::constFind;
+#else
+    inline bool contains(const Key &key) const
+    { return QHash<Key, T>::contains(key); }
+    inline int remove(const Key &key)
+    { return QHash<Key, T>::remove(key); }
+    inline int count(const Key &key) const
+    { return QHash<Key, T>::count(key); }
+    inline int count() const
+    { return QHash<Key, T>::count(); }
+    inline typename QHash<Key, T>::iterator find(const Key &key)
+    { return QHash<Key, T>::find(key); }
+    inline typename QHash<Key, T>::const_iterator find(const Key &key) const
+    { return QHash<Key, T>::find(key); }
+    inline typename QHash<Key, T>::const_iterator constFind(const Key &key) const
+    { return QHash<Key, T>::constFind(key); }
+#endif
+
+    bool contains(const Key &key, const T &value) const;
+
+    int remove(const Key &key, const T &value);
+
+    int count(const Key &key, const T &value) const;
+
+    typename QHash<Key, T>::iterator find(const Key &key, const T &value) {
+        typename QHash<Key, T>::iterator i(find(key));
+        typename QHash<Key, T>::iterator end(this->end());
+        while (i != end && i.key() == key) {
+            if (i.value() == value)
+                return i;
+            ++i;
+        }
+        return end;
+    }
+    typename QHash<Key, T>::const_iterator find(const Key &key, const T &value) const {
+        typename QHash<Key, T>::const_iterator i(constFind(key));
+        typename QHash<Key, T>::const_iterator end(QHash<Key, T>::constEnd());
+        while (i != end && i.key() == key) {
+            if (i.value() == value)
+                return i;
+            ++i;
+        }
+        return end;
+    }
+    typename QHash<Key, T>::const_iterator constFind(const Key &key, const T &value) const
+        { return find(key, value); }
 private:
     T &operator[](const Key &key);
     const T operator[](const Key &key) const;
 };
 
 template <class Key, class T>
-Q_INLINE_TEMPLATE Q_TYPENAME QHash<Key, T>::iterator QMultiHash<Key, T>::replace(const Key &akey, const T &avalue)
-{ return QHash<Key, T>::insert(akey, avalue); }
+Q_INLINE_TEMPLATE bool QMultiHash<Key, T>::contains(const Key &key, const T &value) const
+{
+    return constFind(key, value) != QHash<Key, T>::constEnd();
+}
 
 template <class Key, class T>
-Q_INLINE_TEMPLATE Q_TYPENAME QHash<Key, T>::iterator QMultiHash<Key, T>::insert(const Key &akey, const T &avalue)
-{ return QHash<Key, T>::insertMulti(akey, avalue); }
+Q_INLINE_TEMPLATE int QMultiHash<Key, T>::remove(const Key &key, const T &value)
+{
+    int n = 0;
+    typename QHash<Key, T>::iterator i(find(key));
+    typename QHash<Key, T>::iterator end(QHash<Key, T>::end());
+    while (i != end && i.key() == key) {
+        if (i.value() == value) {
+            i = erase(i);
+            ++n;
+        } else {
+            ++i;
+        }
+    }
+    return n;
+}
 
+template <class Key, class T>
+Q_INLINE_TEMPLATE int QMultiHash<Key, T>::count(const Key &key, const T &value) const
+{
+    int n = 0;
+    typename QHash<Key, T>::const_iterator i(constFind(key));
+    typename QHash<Key, T>::const_iterator end(QHash<Key, T>::constEnd());
+    while (i != end && i.key() == key) {
+        if (i.value() == value)
+            ++n;
+        ++i;
+    }
+    return n;
+}
 
 Q_DECLARE_ASSOCIATIVE_ITERATOR(Hash)
 Q_DECLARE_MUTABLE_ASSOCIATIVE_ITERATOR(Hash)
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QHASH_H
