@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -30,6 +48,10 @@
 #include <QtCore/qvariant.h>
 #include <QtGui/qicon.h>
 
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_ACTION
@@ -37,14 +59,16 @@ QT_MODULE(Gui)
 class QMenu;
 class QActionGroup;
 class QActionPrivate;
+class QGraphicsWidget;
 
 class Q_GUI_EXPORT QAction : public QObject
 {
     Q_OBJECT
     Q_DECLARE_PRIVATE(QAction)
 
+    Q_ENUMS(MenuRole)
     Q_PROPERTY(bool checkable READ isCheckable WRITE setCheckable)
-    Q_PROPERTY(bool checked READ isChecked WRITE setChecked NOTIFY toggled)
+    Q_PROPERTY(bool checked READ isChecked WRITE setChecked DESIGNABLE isCheckable NOTIFY toggled)
     Q_PROPERTY(bool enabled READ isEnabled WRITE setEnabled)
     Q_PROPERTY(QIcon icon READ icon WRITE setIcon)
     Q_PROPERTY(QString text READ text WRITE setText)
@@ -56,10 +80,15 @@ class Q_GUI_EXPORT QAction : public QObject
 #ifndef QT_NO_SHORTCUT
     Q_PROPERTY(QKeySequence shortcut READ shortcut WRITE setShortcut)
     Q_PROPERTY(Qt::ShortcutContext shortcutContext READ shortcutContext WRITE setShortcutContext)
+    Q_PROPERTY(bool autoRepeat READ autoRepeat WRITE setAutoRepeat)
 #endif
     Q_PROPERTY(bool visible READ isVisible WRITE setVisible)
+    Q_PROPERTY(MenuRole menuRole READ menuRole WRITE setMenuRole)
+    Q_PROPERTY(bool iconVisibleInMenu READ isIconVisibleInMenu WRITE setIconVisibleInMenu)
 
 public:
+    enum MenuRole { NoRole, TextHeuristicRole, ApplicationSpecificRole, AboutQtRole,
+                    AboutRole, PreferencesRole, QuitRole };
     explicit QAction(QObject* parent);
     QAction(const QString &text, QObject* parent);
     QAction(const QIcon &icon, const QString &text, QObject* parent);
@@ -98,18 +127,25 @@ public:
     QMenu *menu() const;
     void setMenu(QMenu *menu);
 #endif
-    
+
     void setSeparator(bool b);
     bool isSeparator() const;
 
 #ifndef QT_NO_SHORTCUT
     void setShortcut(const QKeySequence &shortcut);
     QKeySequence shortcut() const;
-    
+
+    void setShortcuts(const QList<QKeySequence> &shortcuts);
+    void setShortcuts(QKeySequence::StandardKey);
+    QList<QKeySequence> shortcuts() const;
+
     void setShortcutContext(Qt::ShortcutContext context);
     Qt::ShortcutContext shortcutContext() const;
+
+    void setAutoRepeat(bool);
+    bool autoRepeat() const;
 #endif
-    
+
     void setFont(const QFont &font);
     QFont font() const;
 
@@ -129,6 +165,12 @@ public:
     void activate(ActionEvent event);
     bool showStatusText(QWidget *widget=0);
 
+    void setMenuRole(MenuRole menuRole);
+    MenuRole menuRole() const;
+
+    void setIconVisibleInMenu(bool visible);
+    bool isIconVisibleInMenu() const;
+
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT void setMenuText(const QString &text) { setText(text); }
     inline QT3_SUPPORT QString menuText() const { return text(); }
@@ -145,8 +187,14 @@ public:
 
     QWidget *parentWidget() const;
 
+    QList<QWidget *> associatedWidgets() const;
+#ifndef QT_NO_GRAPHICSVIEW
+    QList<QGraphicsWidget *> associatedGraphicsWidgets() const; // ### suboptimal
+#endif
+
 protected:
     bool event(QEvent *);
+    QAction(QActionPrivate &dd, QObject *parent);
 
 public Q_SLOTS:
 #ifdef QT3_SUPPORT
@@ -175,15 +223,24 @@ private:
 #ifdef QT3_SUPPORT
     friend class QMenuItem;
 #endif
+    friend class QGraphicsWidget;
     friend class QWidget;
     friend class QActionGroup;
     friend class QMenu;
+    friend class QMenuPrivate;
     friend class QMenuBar;
     friend class QShortcutMap;
+    friend class QToolButton;
 };
 
+QT_BEGIN_INCLUDE_NAMESPACE
 #include <QtGui/qactiongroup.h>
+QT_END_INCLUDE_NAMESPACE
 
 #endif // QT_NO_ACTION
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QACTION_H
