@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -27,6 +45,11 @@
 #include <QtGui/qlistview.h>
 #include <QtCore/qvariant.h>
 #include <QtCore/qvector.h>
+#include <QtGui/qitemselectionmodel.h>
+
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
 
 QT_MODULE(Gui)
 
@@ -35,12 +58,14 @@ QT_MODULE(Gui)
 class QListWidget;
 class QListModel;
 class QWidgetItemData;
+class QListWidgetItemPrivate;
 
 class Q_GUI_EXPORT QListWidgetItem
 {
     friend class QListModel;
+    friend class QListWidget;
 public:
-    enum { Type = 0, UserType = 1000 };
+    enum ItemType { Type = 0, UserType = 1000 };
     explicit QListWidgetItem(QListWidget *view = 0, int type = Type);
     explicit QListWidgetItem(const QString &text, QListWidget *view = 0, int type = Type);
     explicit QListWidgetItem(const QIcon &icon, const QString &text,
@@ -52,8 +77,14 @@ public:
 
     inline QListWidget *listWidget() const { return view; }
 
+    inline void setSelected(bool select);
+    inline bool isSelected() const;
+
+    inline void setHidden(bool hide);
+    inline bool isHidden() const;
+
     inline Qt::ItemFlags flags() const { return itemFlags; }
-    inline void setFlags(Qt::ItemFlags flags);
+    void setFlags(Qt::ItemFlags flags);
 
     inline QString text() const
         { return data(Qt::DisplayRole).toString(); }
@@ -93,15 +124,25 @@ public:
     virtual void setBackgroundColor(const QColor &color)
         { setData(Qt::BackgroundColorRole, color); }
 
+    inline QBrush background() const
+        { return qvariant_cast<QBrush>(data(Qt::BackgroundRole)); }
+    inline void setBackground(const QBrush &brush)
+        { setData(Qt::BackgroundRole, brush); }
+
     inline QColor textColor() const
         { return qvariant_cast<QColor>(data(Qt::TextColorRole)); }
     inline void setTextColor(const QColor &color)
         { setData(Qt::TextColorRole, color); }
 
+    inline QBrush foreground() const
+        { return qvariant_cast<QBrush>(data(Qt::ForegroundRole)); }
+    inline void setForeground(const QBrush &brush)
+        { setData(Qt::ForegroundRole, brush); }
+
     inline Qt::CheckState checkState() const
         { return static_cast<Qt::CheckState>(data(Qt::CheckStateRole).toInt()); }
     inline void setCheckState(Qt::CheckState state)
-        { setData(Qt::CheckStateRole, state); }
+        { setData(Qt::CheckStateRole, static_cast<int>(state)); }
 
     inline QSize sizeHint() const
         { return qvariant_cast<QSize>(data(Qt::SizeHintRole)); }
@@ -123,15 +164,12 @@ public:
 
 private:
     int rtti;
-    QVector<QWidgetItemData> values;
+    QVector<void *> dummy;
     QListWidget *view;
-    QListModel *model;
+    QListWidgetItemPrivate *d;
     Qt::ItemFlags itemFlags;
 };
 
-inline void QListWidgetItem::setFlags(Qt::ItemFlags aflags)
-{ itemFlags = aflags; }
-
 inline void QListWidgetItem::setText(const QString &atext)
 { setData(Qt::DisplayRole, atext); }
 
@@ -166,6 +204,7 @@ class Q_GUI_EXPORT QListWidget : public QListView
     Q_OBJECT
     Q_PROPERTY(int count READ count)
     Q_PROPERTY(int currentRow READ currentRow WRITE setCurrentRow NOTIFY currentRowChanged USER true)
+    Q_PROPERTY(bool sortingEnabled READ isSortingEnabled WRITE setSortingEnabled)
 
     friend class QListWidgetItem;
     friend class QListModel;
@@ -186,15 +225,19 @@ public:
 
     QListWidgetItem *currentItem() const;
     void setCurrentItem(QListWidgetItem *item);
+    void setCurrentItem(QListWidgetItem *item, QItemSelectionModel::SelectionFlags command);
 
     int currentRow() const;
     void setCurrentRow(int row);
+    void setCurrentRow(int row, QItemSelectionModel::SelectionFlags command);
 
     QListWidgetItem *itemAt(const QPoint &p) const;
     inline QListWidgetItem *itemAt(int x, int y) const;
     QRect visualItemRect(const QListWidgetItem *item) const;
 
     void sortItems(Qt::SortOrder order = Qt::AscendingOrder);
+    void setSortingEnabled(bool enable);
+    bool isSortingEnabled() const;
 
     void editItem(QListWidgetItem *item);
     void openPersistentEditor(QListWidgetItem *item);
@@ -202,6 +245,7 @@ public:
 
     QWidget *itemWidget(QListWidgetItem *item) const;
     void setItemWidget(QListWidgetItem *item, QWidget *widget);
+    inline void removeItemWidget(QListWidgetItem *item);
 
     bool isItemSelected(const QListWidgetItem *item) const;
     void setItemSelected(const QListWidgetItem *item, bool select);
@@ -210,6 +254,7 @@ public:
 
     bool isItemHidden(const QListWidgetItem *item) const;
     void setItemHidden(const QListWidgetItem *item, bool hide);
+    void dropEvent(QDropEvent *event);
 
 public Q_SLOTS:
     void scrollToItem(const QListWidgetItem *item, QAbstractItemView::ScrollHint hint = EnsureVisible);
@@ -244,25 +289,47 @@ protected:
 
 private:
     void setModel(QAbstractItemModel *model);
+    Qt::SortOrder sortOrder() const;
 
     Q_DECLARE_PRIVATE(QListWidget)
     Q_DISABLE_COPY(QListWidget)
 
-    Q_PRIVATE_SLOT(d_func(), void emitItemPressed(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemDoubleClicked(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemActivated(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemEntered(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitItemChanged(const QModelIndex &index))
-    Q_PRIVATE_SLOT(d_func(), void emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemPressed(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemDoubleClicked(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemActivated(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemEntered(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitItemChanged(const QModelIndex &index))
+    Q_PRIVATE_SLOT(d_func(), void _q_emitCurrentItemChanged(const QModelIndex &previous, const QModelIndex &current))
+    Q_PRIVATE_SLOT(d_func(), void _q_sort())
+    Q_PRIVATE_SLOT(d_func(), void _q_dataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight))
 };
 
+inline void QListWidget::removeItemWidget(QListWidgetItem *aItem)
+{ setItemWidget(aItem, 0); }
+
 inline void QListWidget::addItem(QListWidgetItem *aitem)
 { insertItem(count(), aitem); }
 
 inline QListWidgetItem *QListWidget::itemAt(int ax, int ay) const
 { return itemAt(QPoint(ax, ay)); }
 
+inline void QListWidgetItem::setSelected(bool aselect)
+{ if (view) view->setItemSelected(this, aselect); }
+
+inline bool QListWidgetItem::isSelected() const
+{ return (view ? view->isItemSelected(this) : false); }
+
+inline void QListWidgetItem::setHidden(bool ahide)
+{ if (view) view->setItemHidden(this, ahide); }
+
+inline bool QListWidgetItem::isHidden() const
+{ return (view ? view->isItemHidden(this) : false); }
+
 #endif // QT_NO_LISTWIDGET
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QLISTWIDGET_H
