@@ -1,23 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2006 Trolltech ASA. All rights reserved.
+** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -29,6 +47,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 #ifndef QT_NO_PRINTER
@@ -40,6 +60,7 @@ QT_MODULE(Gui)
 class QPrinterPrivate;
 class QPaintEngine;
 class QPrintEngine;
+class QPrinterInfo;
 
 class Q_GUI_EXPORT QPrinter : public QPaintDevice
 {
@@ -48,36 +69,51 @@ public:
     enum PrinterMode { ScreenResolution, PrinterResolution, HighResolution };
 
     explicit QPrinter(PrinterMode mode = ScreenResolution);
+    explicit QPrinter(const QPrinterInfo& printer, PrinterMode mode = ScreenResolution);
     ~QPrinter();
 
     int devType() const;
 
     enum Orientation { Portrait, Landscape };
 
-    enum PageSize    { A4, B5, Letter, Legal, Executive,
-		       A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
-		       B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
-		       DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom };
+#ifndef Q_QDOC
+    enum PageSize { A4, B5, Letter, Legal, Executive,
+                    A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                    B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                    DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom, NPaperSize = Custom };
+    typedef PageSize PaperSize;
+#else
+    enum PageSize { A4, B5, Letter, Legal, Executive,
+                    A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                    B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                    DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom };
+    enum PaperSize { A4, B5, Letter, Legal, Executive,
+                     A0, A1, A2, A3, A5, A6, A7, A8, A9, B0, B1,
+                     B10, B2, B3, B4, B6, B7, B8, B9, C5E, Comm10E,
+                     DLE, Folio, Ledger, Tabloid, Custom, NPageSize = Custom, NPaperSize = Custom };
+#endif
 
     enum PageOrder   { FirstPageFirst,
-		       LastPageFirst };
+                       LastPageFirst };
 
     enum ColorMode   { GrayScale,
-		       Color };
+                       Color };
 
     enum PaperSource { OnlyOne,
-		       Lower,
-		       Middle,
-		       Manual,
-		       Envelope,
+                       Lower,
+                       Middle,
+                       Manual,
+                       Envelope,
                        EnvelopeManual,
-		       Auto,
-		       Tractor,
-		       SmallFormat,
+                       Auto,
+                       Tractor,
+                       SmallFormat,
                        LargeFormat,
-		       LargeCapacity,
-		       Cassette,
-		       FormSource };
+                       LargeCapacity,
+                       Cassette,
+                       FormSource,
+                       MaxPageSource
+    };
 
     enum PrinterState { Idle,
                         Active,
@@ -89,6 +125,23 @@ public:
     // ### Qt 5: Merge with QAbstractPrintDialog::PrintRange
     enum PrintRange { AllPages, Selection, PageRange };
 
+    enum Unit {
+        Millimeter,
+        Point,
+        Inch,
+        Pica,
+        Didot,
+        Cicero,
+        DevicePixel
+    };
+
+    enum DuplexMode {
+        DuplexNone = 0,
+        DuplexAuto,
+        DuplexLongSide,
+        DuplexShortSide
+    };
+
 #ifdef QT3_SUPPORT
     enum PrinterOption { PrintToFile, PrintSelection, PrintPageRange };
 #endif // QT3_SUPPORT
@@ -99,6 +152,8 @@ public:
     void setPrinterName(const QString &);
     QString printerName() const;
 
+    bool isValid() const;
+
     void setOutputFileName(const QString &);
     QString outputFileName()const;
 
@@ -117,6 +172,12 @@ public:
     void setPageSize(PageSize);
     PageSize pageSize() const;
 
+    void setPaperSize(PaperSize);
+    PaperSize paperSize() const;
+
+    void setPaperSize(const QSizeF &paperSize, Unit unit);
+    QSizeF paperSize(Unit unit) const;
+
     void setPageOrder(PageOrder);
     PageOrder pageOrder() const;
 
@@ -138,8 +199,15 @@ public:
     void setPaperSource(PaperSource);
     PaperSource paperSource() const;
 
+    void setDuplex(DuplexMode duplex);
+    DuplexMode duplex() const;
+
     QList<int> supportedResolutions() const;
 
+#ifdef Q_WS_WIN
+    QList<PaperSource> supportedPaperSources() const;
+#endif
+
     void setFontEmbeddingEnabled(bool enable);
     bool fontEmbeddingEnabled() const;
 
@@ -153,6 +221,8 @@ public:
 
     QRect paperRect() const;
     QRect pageRect() const;
+    QRectF paperRect(Unit) const;
+    QRectF pageRect(Unit) const;
 
 #if !defined(Q_WS_WIN) || defined(qdoc)
     QString printerSelectionOption() const;
@@ -176,10 +246,11 @@ public:
     int fromPage() const;
     int toPage() const;
 
-#ifndef QT_NO_PRINTDIALOG
     void setPrintRange(PrintRange range);
     PrintRange printRange() const;
-#endif
+
+    void setPageMargins(qreal left, qreal top, qreal right, qreal bottom, Unit unit);
+    void getPageMargins(qreal *left, qreal *top, qreal *right, qreal *bottom, Unit unit) const;
 
 #ifdef QT3_SUPPORT
 #ifdef Q_WS_MAC
@@ -213,12 +284,18 @@ protected:
     void setEngines(QPrintEngine *printEngine, QPaintEngine *paintEngine);
 
 private:
+    void init(PrinterMode mode);
+
     Q_DISABLE_COPY(QPrinter)
 
     QPrinterPrivate *d_ptr;
 
-    friend class QPrintDialogWin;
+    friend class QPrintDialogPrivate;
     friend class QAbstractPrintDialog;
+    friend class QAbstractPrintDialogPrivate;
+    friend class QPrintPreviewWidgetPrivate;
+    friend class QTextDocument;
+    friend class QPageSetupWidget;
 };
 
 #ifdef QT3_SUPPORT
@@ -246,6 +323,8 @@ inline void QPrinter::margins(uint *top, uint *left, uint *bottom, uint *right)
 
 #endif // QT_NO_PRINTER
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QPRINTER_H
